#!/usr/bin/perl
# -----------------------------------------------------------------------------
# Programm         : p l a n a l y s e . p l
# -----------------------------------------------------------------------------
# Autor            : Christian Dhl
# Erstellt         : 30. Oktober 2003
# Zuletzt gendert : 30. Oktober 2003
# Aufgabe          : Auszhlungen von Perl-Quellcode
# -----------------------------------------------------------------------------

#------------------------------------------------------------------------------
# Pakete / Pragmas
#------------------------------------------------------------------------------
use diagnostics;
use strict;
use warnings;

use FindBin;
use lib $FindBin::Bin;

use CDtools;


die "Wrong number of parameters, need to get one (the file name)."
    unless 1 == @ARGV;

my $File = shift @ARGV;

die "'$File' is not a text file." unless -T $File;

print STDERR "analysing file '$File' ...\n";

open IN, $File or die "Can't open '$File' : $!";

my $Chars      = 0; # Counter for any char
my $Spaces     = 0; # Counter for whitespace (without line breaks)
my $EmptyLines = 0; # Counter for empty Lines
my $LineBreaks = 0; # Counter for line breaks
my $Comment    = 0; # Counter for comment characters (without white space)
my $Code       = 0; # Counter for code characters (without white space)
my $CodeLines  = 0; # Counter for lines that contain code

while (<IN>) {
    my $codeline = 0;

    $Chars += length;

    if (s/\r?\n$//) {
        ++$LineBreaks;
    }

    unless (/\S/) {
        ++$EmptyLines;
        $Spaces += length;
        next;
    }

    my @line = split //;

    my $incomment = 0;

    for my $c (@line) {
        if ($c =~ /\s/) {
            ++$Spaces;
        }

        if ($incomment) {
            ++$Comment;
        }
        else {
            if ($c eq '#') {
                $incomment = 1;
                ++$Comment; # ? hmmm '#' mitzhlen? Ja
            }
            else {
                ++$Code;
                $codeline = 1;
            }
        }
    }

    ++$CodeLines if $codeline;
}


printf "Number of lines                 : %8s\n".
       "Number of line breaks           : %8s\n".
       "Number of empty lines           : %8s\n".
       "Number of lines with code       : %8s\n".
       "Number of characters            : %8s\n".
       "Number of white space characters: %8s\n".
       "Number of comment characters    : %8s\n".
       "Number of code characters       : %8s\n",
       CDtools::taupu($.         ) ,
       CDtools::taupu($LineBreaks) ,
       CDtools::taupu($EmptyLines) ,
       CDtools::taupu($CodeLines ) ,
       CDtools::taupu($Chars     ) ,
       CDtools::taupu($Spaces    ) ,
       CDtools::taupu($Comment   ) ,
       CDtools::taupu($Code      ) ;

close IN;

__END__

Zu einfach, da auf # in Zeichenketten oder regulren Ausdrcken oder in
Dateinamen etc. keine Rcksicht genommen wird...
